@@ -159,7 +159,7 @@
     <message>
         <location filename="../InfoPage.qml" line="207"/>
         <source>Mieru is a flexible Manga and comic book reader.</source>
-        <translation>Mieru là một ứng dụng đọc Manga và truyện comic đa năng.</translation>
+        <translation>Mieru là một ứng dụng đọc truyện tranh đa năng.</translation>
     </message>
     <message>
         <location filename="../InfoPage.qml" line="243"/>
